@@ -2,5 +2,5 @@
 
 """Add concurrency to methods and functions in a single line of code."""
 
-from .thread import *
-from .process import *
+import lox.worker.thread
+import lox.worker.process
